<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:param name="component">all</xsl:param>
<xsl:param name="xmlFile"></xsl:param>
<xsl:param name="mDescFile"></xsl:param>

<xsl:template match="/">
  <xsl:apply-templates select="FEATURE_MATRIX"/>
</xsl:template>

<xsl:template match="FEATURE_MATRIX">
  <xsl:choose>
  <xsl:when test="$component='all'">
    <xsl:apply-templates select="FEATURE">
     <xsl:sort select="@name"/>
    </xsl:apply-templates>
  </xsl:when>
  <xsl:when test="$component='delta'">
    <xsl:apply-templates select="FEATURE[@status!='']">
     <xsl:sort select="@name"/>
    </xsl:apply-templates>
  </xsl:when>
  <xsl:otherwise>
    <xsl:apply-templates select="FEATURE[@name=$component]"/>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="FEATURE">
  <font size="3">
  <H3>Feature Name = <xsl:value-of select="@name"/>
    <xsl:if test="@status!=''">
      <font color="red"> (<xsl:value-of select="@status"/>)</font>
    </xsl:if>
  </H3>
  </font>
  <div style="margin-left:20px;margin-bottom:1em;font-size:10pt">
    <xsl:value-of select="DESCRIPTION"/>  
  </div>
  <xsl:call-template name="associate-feature"/>
  <xsl:call-template name="service-type"/>
  <xsl:call-template name="termination-type"/>
  <xsl:call-template name="trigger"/>
  <xsl:call-template name="applies-to"/>
  <xsl:call-template name="feature-profile"/>
  <xsl:call-template name="subscriber-feature-data"/>
  <xsl:call-template name="feature-config"/>
</xsl:template>

<xsl:template match="DESCRIPTION">
  <xsl:if test="current()!=''">
    <tr>
      <td width="150"><b>Description: </b></td>
      <td>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="current()"/>
        </xsl:call-template>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="applies-to">
  <xsl:if test="APPLIES_TO!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Applies To:</b></li>
      <xsl:for-each select="APPLIES_TO/TABLE">
        <dd>
        <xsl:if test="not(@status!='')">
      	  <xsl:choose>
      	  <xsl:when test="current()='SLE'">
			Screening List Editing   	
      	  </xsl:when>
      	  <xsl:when test="current()='SUBSCRIBER_SIP_TRIGGER_PROFILE'">
			Subscirber SIP Trigger Profile   	
      	  </xsl:when>      	  
      	  <xsl:when test="current()='SUBSCRIBER_TOD_SCHEDULE'">
			Subscriber TOD Schedule   	
      	  </xsl:when>
      	  </xsl:choose>
      	</xsl:if>
        <xsl:if test="@status!=''">
      	  <xsl:choose>
      	  <xsl:when test="current()='SLE'">
			<font color='red'>Screening List Editing (<xsl:value-of select="@status"/>)</font>   	
      	  </xsl:when>
      	  <xsl:when test="current()='SUBSCRIBER_SIP_TRIGGER_PROFILE'">
			<font color='red'>Subscirber SIP Trigger Profile (<xsl:value-of select="@status"/>)</font>   	
      	  </xsl:when>      	  
      	  <xsl:when test="current()='SUBSCRIBER_TOD_SCHEDULE'">
			<font color='red'>Subscriber TOD Schedule (<xsl:value-of select="@status"/>)</font>   	
      	  </xsl:when>
      	  </xsl:choose>
      	</xsl:if>
      	</dd>
      </xsl:for-each>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="feature-profile">
  <xsl:if test="FEATURE_PROFILE!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Feature Profile:</b></li>
      <br/>
      <xsl:apply-templates select="FEATURE_PROFILE"/>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="subscriber-feature-data">
  <xsl:if test="SUBSCRIBER_FEATURE_DATA!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Subscriber Feature Data:</b></li>
      <br/>
      <xsl:apply-templates select="SUBSCRIBER_FEATURE_DATA"/>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="feature-config">
  <xsl:if test="FEATURE_CONFIG!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Feature Configuration:</b></li>
      <br/>
      <xsl:apply-templates select="FEATURE_CONFIG"/>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template match="FEATURE_CONFIG|FEATURE_PROFILE|SUBSCRIBER_FEATURE_DATA">
  <xsl:variable name="fp" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/../@name]/FEATURE_PROFILE"/>
  <xsl:variable name="sfd" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/../@name]/SUBSCRIBER_FEATURE_DATA"/>
  <xsl:variable name="fc" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/../@name]/FEATURE_CONFIG"/>
  <xsl:variable name="ftype" select="local-name()"/>
  <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
         bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
    <thead bgColor='lightgreen'>
      <th width="30%"><b>Type</b></th>
      <th><b>Description</b></th>
    </thead>
    <xsl:for-each select="TYPE">
      <xsl:sort select="@name"/>
      <xsl:choose>
      <xsl:when test="$ftype='SUBSCRIBER_FEATURE_DATA'">
        <xsl:call-template name="feature-type">
          <xsl:with-param name="doc" select="$sfd/TYPE[@name=current()/@name]"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:when test="$ftype='FEATURE_CONFIG'">
        <xsl:call-template name="feature-type">
          <xsl:with-param name="doc" select="$fc/TYPE[@name=current()/@name]"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="feature-type">
          <xsl:with-param name="doc" select="$fp/TYPE[@name=current()/@name]"/>
        </xsl:call-template>
      </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>  
  </table>
</xsl:template>

<xsl:template name="feature-type">
  <xsl:param name="doc"/>
  <tr bgColor='lightyellow'>
    <td>
      <xsl:if test="not(@status!='') and not(../@status='new')">	
		<xsl:value-of select="@name"/>
      </xsl:if>
      <xsl:if test="@status!='' or ../@status='new'">
        <font color='red'><xsl:value-of select="@name"/></font>
      </xsl:if>
    </td>
    <td>
      <table border="0" width="100%" style="font-size:8pt">
        <xsl:call-template name="status"/>
        <xsl:call-template name="description">
          <xsl:with-param name="doc" select="$doc"/>
        </xsl:call-template>
        <xsl:apply-templates select="STRING|INTEGER|DIGITS|BOOLEAN"/>
        <xsl:apply-templates select="DEFAULT_VALUE"/>
        <xsl:apply-templates select="FOREIGN_KEY"/>
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template name="description">
  <xsl:param name="doc"/>
  <xsl:variable name="desc" select="$doc/DESCRIPTION"/>
  <xsl:if test="$desc!=''">
    <tr>
      <td width="150"><b>Description: </b></td>
      <td>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="$desc/text()"/>
        </xsl:call-template>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="status">
  <xsl:if test="@status!=''">
    <tr>
      <td width="150"><font color="red"><b>Status: </b></font></td>
      <td><font color="red"><b>
        This is <xsl:value-of select="@status"/>.
      </b></font></td>
    </tr>
  </xsl:if>
  <xsl:if test="not(@status!='') and ../@status='new'">
    <tr>
      <td width="150"><font color="red"><b>Status: </b></font></td>
      <td><font color="red"><b>
        This is <xsl:value-of select="../@status"/>.
      </b></font></td>
    </tr>
  </xsl:if>  
</xsl:template>  
     
<xsl:template match="STRING">
  <tr>
    <xsl:if test="not(@status!='')">
      <td width="150"><b>Data Type: </b></td>
    </xsl:if>
    <xsl:if test="@status!=''">
      <td width="150">
        <b><font color="red">Data Type (<xsl:value-of select="@status"/>): </font></b>
      </td>
    </xsl:if>
     <td>
       <xsl:if test="@status!=''">
         <font color="red">
           <xsl:call-template name="display-string"/>
         </font>
       </xsl:if>
       <xsl:if test="not(@status!='')">
         <xsl:call-template name="display-string"/>
       </xsl:if>
     </td>
  </tr>
</xsl:template>
  
<xsl:template name="display-string">  
  STRING
  <xsl:choose>
  <xsl:when test="CHK_POS_VAL='U'">
    ( Data is case-insensitive and stored as uppercase in database. )<br/>
  </xsl:when>
  <xsl:when test="CHK_POS_VAL='L'">
    ( Data is case-insensitive and stored as lowercase in database. )<br/>
  </xsl:when>
  <xsl:when test="CHK_POS_VAL='Y'">
    ( Data is case-sensitive and stored as it is in database. )<br/>
  </xsl:when>
  <xsl:otherwise>
  </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="VALUE!=''">
    <b>Possible Value : </b>
      <xsl:for-each select="VALUE">
        <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
        <xsl:value-of select="current()"/>
      </xsl:for-each>
      <br/>
    </xsl:if>
</xsl:template>

<xsl:template match="INTEGER">
  <xsl:if test="FROM_VALUE!=''">
    <xsl:variable name="text">
      INTEGER ( <xsl:value-of select="FROM_VALUE"/> - <xsl:value-of select="TO_VALUE"/> )
    </xsl:variable>
    <xsl:call-template name="display-column-attr">
      <xsl:with-param name="item" select="'Data Type'"/>
      <xsl:with-param name="text" select="$text"/>
  </xsl:call-template>
  </xsl:if>
  <xsl:if test="not(FROM_VALUE!='')">
    <xsl:call-template name="display-column-attr">
      <xsl:with-param name="item" select="'Data Type'"/>
      <xsl:with-param name="text" select="'INTEGER'"/>
  </xsl:call-template>
  </xsl:if>
</xsl:template>

<xsl:template match="DIGITS">
  <xsl:if test="FROM_VALUE!=''">
    <xsl:variable name="text">
      DIGITS ( <xsl:value-of select="FROM_VALUE"/> - <xsl:value-of select="TO_VALUE"/> )
    </xsl:variable>
    <xsl:call-template name="display-column-attr">
      <xsl:with-param name="item" select="'Data Type'"/>
      <xsl:with-param name="text" select="$text"/>
  </xsl:call-template>
  </xsl:if>
  <xsl:if test="not(FROM_VALUE!='')">
    <xsl:call-template name="display-column-attr">
      <xsl:with-param name="item" select="'Data Type'"/>
      <xsl:with-param name="text" select="'DIGITS'"/>
  </xsl:call-template>
  </xsl:if>
</xsl:template>

<xsl:template match="BOOLEAN">
  <xsl:call-template name="display-column-attr">
    <xsl:with-param name="item" select="'Data Type'"/>
    <xsl:with-param name="text" select="'BOOLEAN ( Y/N )'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="DEFAULT_VALUE">
  <xsl:call-template name="display-column-attr">
    <xsl:with-param name="item" select="'Default Value'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="FOREIGN_KEY">
  <xsl:if test="TABLENAME!=''">
    <xsl:variable name="text">
      <xsl:value-of select="TABLENAME"/> ( <xsl:value-of select="TOKENNAME"/> )
    </xsl:variable>
    <xsl:call-template name="display-column-attr">
      <xsl:with-param name="item" select="'Foreign Key'"/>
      <xsl:with-param name="text" select="$text"/>
  </xsl:call-template>
  </xsl:if>
</xsl:template>

<xsl:template name="display-column-attr">
  <xsl:param name="item"/>
  <xsl:param name="status"/>
  <xsl:param name="text"/>
  <xsl:if test="current()!='' or $text!=''">
    <tr>
      <xsl:choose>
      <xsl:when test="$status!='' or @status!=''">
        <td width="150"><font color="red"><b>
          <xsl:choose>
          <xsl:when test="@status!=''">
            <xsl:value-of select="$item"/> (<xsl:value-of select="@status"/>):
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$item"/> (<xsl:value-of select="$status"/>):
          </xsl:otherwise>
          </xsl:choose>
        </b></font></td>
        <td><font color="red">
          <xsl:if test="$text!=''">
            <xsl:call-template name="display-column-attr-content">
              <xsl:with-param name="text" select="$text"/>
            </xsl:call-template>
          </xsl:if>
          <xsl:if test="not($text!='')">
            <xsl:call-template name="display-column-attr-content">
              <xsl:with-param name="text" select="current()"/>
            </xsl:call-template>
          </xsl:if>
        </font></td>
      </xsl:when>
      <xsl:otherwise>
        <td width="150"><b><xsl:value-of select="$item"/>:</b></td>
        <td>
          <xsl:if test="$text!=''">
            <xsl:call-template name="display-column-attr-content">
              <xsl:with-param name="text" select="$text"/>
            </xsl:call-template>
          </xsl:if>
          <xsl:if test="not($text!='')">
            <xsl:call-template name="display-column-attr-content">
              <xsl:with-param name="text" select="current()"/>
            </xsl:call-template>
          </xsl:if>
        </td>
      </xsl:otherwise>
      </xsl:choose>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="display-column-attr-content">
  <xsl:param name="text"/>
  <xsl:call-template name="replace-string">
    <xsl:with-param name="text" select="$text"/>
    <xsl:with-param name="replace" select="','"/>
    <xsl:with-param name="with" select="', '"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="replace-string">
  <xsl:param name="text"/>
  <xsl:param name="replace"/>
  <xsl:param name="with"/>
  <xsl:choose>
    <xsl:when test="contains($text,$replace)">
      <xsl:value-of select="substring-before($text,$replace)"/>
      <xsl:value-of select="$with"/>
      <xsl:call-template name="replace-string">
        <xsl:with-param name="text" select="substring-after($text,$replace)"/>
        <xsl:with-param name="replace" select="$replace"/>
        <xsl:with-param name="with" select="$with"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$text"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="break">
  <xsl:param name="text"/>
   <xsl:choose>
   <xsl:when test="contains($text, '&#xa;')">
      <xsl:variable name="lineStr" select="substring-before($text,'&#xa;')"/>
      <xsl:value-of select="$lineStr"/>
      <xsl:if test="$lineStr!=''"><br/></xsl:if>
      <xsl:call-template name="break">
          <xsl:with-param name="text" select="substring-after($text,'&#xa;')"/>
      </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
        <xsl:value-of select="$text"/>
   </xsl:otherwise>
   </xsl:choose>
</xsl:template>

<xsl:template name="associate-feature">
  <xsl:variable name="desc" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/@name]/ASSOCIATE_FEATURE"/>
  <xsl:if test="$desc!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <dl>
        <li><b>Associate Feature: </b></li>
          <dd>
          <xsl:for-each select="$desc/FEATURE_NAME">
    		<xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
    		<xsl:value-of select="current()"/>
  		  </xsl:for-each>
  		  </dd>
      </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="service-type">
  <xsl:variable name="desc" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/@name]/SERVICE_TYPE"/>
  <xsl:if test="$desc!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <dl>
        <li><b>Service Type: </b></li>
        <dd><xsl:apply-templates select="$desc"/></dd>
      </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="termination-type">
  <xsl:variable name="desc" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/@name]/TERMINATION_TYPE"/>
  <xsl:if test="$desc!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <dl>
        <li><b>Termination Type: </b></li>
        <dd><xsl:apply-templates select="$desc"/></dd>
      </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="trigger">
  <xsl:variable name="desc" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/@name]/TRIGGER"/>
  <xsl:if test="$desc!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Trigger:</b></li>
      <br/>
      <table border="1" width="50%" style="font-size:8pt">
        <thead bgColor='lightyellow'>
          <th><b>Trigger Detection Point</b></th>
          <th><b>Trigger ID</b></th>
          <th><b>Trigger Type</b></th>
        </thead>
        <xsl:apply-templates select="$desc/TRIGGER_INFO[@status!='removed' or not(@status!='')]"/>
      </table>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template match="TRIGGER_INFO">
  <tr>
    <td><xsl:value-of select="TRIGGER_DETECTION_POINT"/></td>
    <td><xsl:value-of select="TRIGGER_ID"/></td>
    <td><xsl:value-of select="TRIGGER_TYPE"/></td>
  </tr>
</xsl:template>

</xsl:stylesheet>

