<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:import href="BTS-Feature.xsl"/>

<xsl:template match="/">
  <xsl:call-template name="generate-code"/>
  <HR/>
  <xsl:apply-templates select="FEATURE_MATRIX"/>
</xsl:template>

<xsl:template match="FEATURE">
  <font size="3">
  <H3>Feature Name = <xsl:value-of select="@name"/>
    <xsl:if test="@status!=''">
      <font color="red"> (<xsl:value-of select="@status"/>)</font>
    </xsl:if>
  </H3>
  </font>
  <div style="margin-left:20px;margin-bottom:1em;font-size:10pt">
    <xsl:value-of select="DESCRIPTION"/>  
  </div>
  <xsl:call-template name="associate-feature"/>
  <xsl:call-template name="service-type"/>
  <xsl:call-template name="termination-type"/>
  <xsl:call-template name="trigger"/>
  <xsl:call-template name="applies-to"/>
  <xsl:call-template name="feature-profile"/>
  <xsl:call-template name="subscriber-feature-data"/>
  <xsl:call-template name="feature-config"/>
  <xsl:apply-templates select="CHANGE_HISTORY"/>
</xsl:template>

<xsl:template name="generate-code">
<div style="margin-left:20px;font-size:8pt">
  <table border="0" width="95%" style="font-size:8pt">
    <tr align="right">
    <td>
        <form name="select">
          <input type="hidden" name="xmlFile" value="{$xmlFile}"/>
          <input type="hidden" name="component" value="{$component}"/>
          <input type="button" value="Generate Code"
                 style="font-family: verdana; font-size: 12px;"
                 onclick="generateCode(getFeatureParameters())"/>
        </form>
      </td>
    </tr>
  </table>
</div>
</xsl:template>

<xsl:template name="feature-type">
  <tr bgColor='lightyellow'>
    <td>
      <xsl:if test="not(@status!='')">	
		<xsl:value-of select="@name"/>
      </xsl:if>
      <xsl:if test="@status!=''">   
        <font color='red'><xsl:value-of select="@name"/></font>
      </xsl:if>
    </td>
    <td>
      <table border="0" width="100%" style="font-size:8pt">
        <xsl:call-template name="status"/>
        <xsl:apply-templates select="DESCRIPTION"/>
        <xsl:apply-templates select="STRING|INTEGER|DIGITS|BOOLEAN"/>
        <xsl:apply-templates select="DEFAULT_VALUE"/>
        <xsl:apply-templates select="FOREIGN_KEY"/>
        <xsl:call-template name="change-history"/>
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template match="CHANGE_HISTORY">
  <xsl:if test="current()!=''">
	<div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <dl>
        <li><b>Change History:</b></li>
        <dd>
          <xsl:call-template name="break">
            <xsl:with-param name="text" select="current()"/>
          </xsl:call-template>
        </dd>
      </dl>
    </div>
  </xsl:if>  
</xsl:template>

<xsl:template name="change-history">
  <xsl:variable name="history" select="CHANGE_HISTORY"/>
  <xsl:if test="$history!=''">
    <tr>
      <td width="150"><b>Change History: </b></td>
      <td>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="$history"/>
        </xsl:call-template>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="associate-feature">
  <xsl:if test="ASSOCIATE_FEATURE!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <dl>
        <li><b>Associate Feature: </b></li>
          <dd>
          <xsl:for-each select="ASSOCIATE_FEATURE/FEATURE_NAME">
    		<xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
    		<xsl:value-of select="current()"/>
  		  </xsl:for-each>
  		  </dd>
      </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="service-type">
  <xsl:if test="SERVICE_TYPE!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <dl>
        <li><b>Service Type: </b></li>
        <dd><xsl:apply-templates select="SERVICE_TYPE"/></dd>
      </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="termination-type">
  <xsl:if test="TERMINATION_TYPE!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <dl>
        <li><b>Termination Type: </b></li>
        <dd><xsl:apply-templates select="TERMINATION_TYPE"/></dd>
      </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="trigger">
  <xsl:if test="TRIGGER!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Trigger:</b></li>
      <br/>
      <table border="1" width="50%" style="font-size:8pt">
        <thead bgColor='lightyellow'>
          <th><b>Trigger Detection Point</b></th>
          <th><b>Trigger ID</b></th>
          <th><b>Trigger Type</b></th>
        </thead>
        <xsl:apply-templates select="TRIGGER/TRIGGER_INFO"/>
      </table>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template match="TRIGGER_INFO">
  <tr>
    <xsl:if test="@status!=''">
      <td bgColor='pink'><font color="red"><xsl:value-of select="TRIGGER_DETECTION_POINT"/> (<xsl:value-of select="@status"/>)</font></td>
      <td bgColor='pink'><font color="red"><xsl:value-of select="TRIGGER_ID"/></font></td>
      <td bgColor='pink'><font color="red"><xsl:value-of select="TRIGGER_TYPE"/></font></td>
    </xsl:if>
    <xsl:if test="not(@status!='')">
      <td><xsl:value-of select="TRIGGER_DETECTION_POINT"/></td>
      <td><xsl:value-of select="TRIGGER_ID"/></td>
      <td><xsl:value-of select="TRIGGER_TYPE"/></td>
    </xsl:if>
  </tr>
</xsl:template>

</xsl:stylesheet>

